import vue from "rollup-plugin-vue";
import node from "@rollup/plugin-node-resolve";
import cjs from "@rollup/plugin-commonjs";
import babel from "@rollup/plugin-babel";
import typescript from "rollup-plugin-typescript2";

const babelOptions = {
  babelHelpers: "bundled",
};

const vuePluginConfig = {
  template: {
    isProduction: true,
    compilerOptions: {
      whitespace: "condense",
    },
  },
};

const typescriptConfig = {
  typescript: require("typescript"),
};

const nodeConfig = {
  extensions: [".vue", ".ts"],
};

export default () => [
  {
    input: "src/main.ts",
    external: ["vue"],
    output: {
      format: "esm",
      file: "dist/index.esm.js",
      globals: {
        vue: "Vue",
      },
    },
    plugins: [
      node(nodeConfig),
      typescript(typescriptConfig),
      vue(vuePluginConfig),
      babel(babelOptions),
      cjs(),
    ],
  },
];
