import camelCase from "lodash/camelCase";
import defaultProps from "./defaultProps";
import { BoxPropConfig } from "./types";
import {
  resolvePropConfig,
  expandVariantPropClasses,
  buildClassName,
} from "./utils/box";

export const propKeys: string[] = [];
export const propsMap: Record<string, BoxPropConfig> = {};

/*
 * Map prop config to parser compatible config.
 */
defaultProps.forEach((config) => {
  // Normalize config short-hands
  const resolvedConfig = resolvePropConfig(config);

  // Record prop names so they can be plucked out and processed from
  // the `useBoxProps` hook.
  propKeys.push(resolvedConfig.propName);

  propsMap[resolvedConfig.propName] = resolvedConfig;
});

/**
 * Take an attribute and value; return a classlist to be applied to
 * a component
 */
export function parser(prop: string, value: any): string[] {
  const propKey = camelCase(prop);
  const propConfig = propsMap[propKey];

  let classes = [];

  console.log({ propKey, propConfig });
  // Variant aware props
  if (propConfig.variants) {
    classes = [...expandVariantPropClasses(propConfig, value)];
  } else {
    // One-off props
    classes.push(buildClassName(propConfig, value));
  }

  return classes;
}
