import { App } from "vue";
import kebabCase from "lodash/kebabCase";
import merge from "lodash/merge";
import defaultConfig from "./defaultConfig";
import { RiverConfig } from "./types";
import * as components from "./components";

function getComponentName(name: string, config: RiverConfig) {
  return [config.prefix, kebabCase(name)].join("-").toLowerCase();
}

export default {
  install(app: App, options: Partial<RiverConfig> = {}) {
    const config: RiverConfig = merge({}, defaultConfig, options);

    app.config.globalProperties.$river = {
      config,
    };

    app.provide("$riverConfig", config);

    for (const component in components) {
      // @ts-ignore-next
      app.component(getComponentName(component, config), components[component]);
    }
  },
};
