import camelCase from "lodash/camelCase";
import kebabCase from "lodash/kebabCase";
import omit from "lodash/omit";
import { RiverConfig } from "../types";
import { normalizeClassAsArray } from "./box";

export function applyUtilities(
  attrs: Record<string, any> = {},
  config: RiverConfig
) {
  let classes: string[] = [];

  // Flatten attributes into a class list compatible with vue's
  // v-bind:class binding
  for (let attr in attrs) {
    if (
      config.boxProps.list.indexOf(camelCase(attr)) !== -1 ||
      config.boxProps.list.indexOf(kebabCase(attr)) !== -1
    ) {
      classes = [...classes, ...config.boxProps.parser(attr, attrs[attr])];
    }
  }

  // Remove polymorphic tag prop from attributes as these will be forwarded
  // directly to the resulting html tag
  delete attrs.as;
  delete attrs.is;
  delete attrs.tag;

  return [omit(attrs, config.boxProps.list), classes];
}
