import merge from "lodash/merge";
import uniq from "lodash/uniq";
import classNames from "classnames";
import { h } from "vue";
import { RenderProps } from "../types";
import { applyUtilities } from "./applyUtilities";

export function render(
  defaultTag: string = "div",
  { slots, props, attrs, config, slot = "default" }: RenderProps
) {
  let children = slots.default?.(slot);
  let tag = attrs.tag ?? attrs.as ?? attrs.is ?? defaultTag;

  let [attributes, utilityClasses] = applyUtilities(
    merge({}, attrs, props, { class: [attrs.class, props.class] }),
    config
  );

  // Compile classList and remove duplicate classes (for instance if a prop and a utility class were defined)
  const classes = uniq(
    classNames([props.class, attrs.class, utilityClasses]).split(" ")
  );

  if (classes.length) {
    (attributes as any).class = classes;
  }

  return h(tag, attributes, children);
}
